#import "BWBorkSortPrefPanel.h"

#import "BWBorkSortPreferences.h"
#import "BWLog.h"

static const char *cvsid = "$Id: BWBorkSortPrefPanel.m,v 1.1.1.1 2002/03/25 01:36:49 markd Exp $";
static BWLogModule *logger;

@implementation BWBorkSortPrefPanel

+ (void) initialize
{
    [super initialize];

    logger = [BWLogModule registerModule: @"BWBorkSortPrefPanel"
			  withCVSId: cvsid];

} // initialize


- (id) init
{
    return ([self initWithWindowNibName: @"PrefPanel"  owner: self]);
} // init


- (void) windowDidLoad
{
    NSString *keepFolder;
    BWBorkSortKeepType keepType;
    BWBorkSortPreferences *prefs = [BWBorkSortPreferences defaultPreferences];

    keepFolder = [prefs currentKeepFolder];
    keepType = [prefs keepType];

    BWLog (logger, BWTrace, @"window did load with prefs: %@", prefs);

    [keepFolderField setStringValue: keepFolder];

    if (keepType == BWCopy) {
	[moveCopyCheckbox setState: NO];
    } else if (keepType == BWMove) {
	[moveCopyCheckbox setState: YES];
    }

    {
	NSWindow *window = [self window];
	NSLog (@"ook: %@", [window valueForKey: @"_borderView"]);
    }
    
} // windowDidLoad


- (IBAction) changeKeepType: (id) sender
{
    BWBorkSortPreferences *prefs = [BWBorkSortPreferences defaultPreferences];

    BWLog (logger, BWTrace, 
	   @"changing keep type.  State is %d.", prefs, [sender state]);

    if ([sender state]) {
	[prefs setKeepType: BWMove];
    } else {
	[prefs setKeepType: BWCopy];
    }

} // changeKeepType


- (IBAction) openKeepFolderPanel: (id) sender
{
    NSOpenPanel *panel;

    BWLog (logger, BWNotice, @"opening directory chooser");

    // set up an NSOpenPanel that'll just read directories
    panel = [NSOpenPanel openPanel];
    [panel setCanChooseDirectories: YES];
    [panel setCanChooseFiles: NO];
    [panel setAllowsMultipleSelection: NO];

    [panel beginSheetForDirectory: nil
	   file: nil
	   types: nil
	   modalForWindow: [self window]
	   modalDelegate: self
	   didEndSelector: @selector (openPanelDidEnd:returnCode:contextInfo:)
	   contextInfo: nil];

} // openKeepFolderPanel


- (void) openPanelDidEnd: (NSOpenPanel *) panel  
	      returnCode: (int) code  
	     contextInfo: (void *) rock
{

    if (code == NSOKButton) {
	BWBorkSortPreferences *prefs = [BWBorkSortPreferences defaultPreferences];
	NSArray *filenames;
	NSString *pathname;
	
	filenames = [panel filenames];
	pathname = [filenames objectAtIndex: 0];
	
	BWLog (logger, BWTrace, @"directory chooser returned '%@'",
	       pathname);
	
	// this is the only unique part of this directory chizling
	[prefs setCurrentKeepFolder: pathname];
	[keepFolderField setStringValue: [prefs currentKeepFolder]];

    } else {
	BWLog (logger, BWTrace, @"keep directory chooser closed without OK");
    }

} // openPanelDidEnd


@end // BWBorkSortPrefPanel

